@@ -38,12 +38,12 @@ X264_REVISION="origin/stable"
 X265_HEAD=0
 X265_REVISION="origin/stable"
 LIBVPX_HEAD=0
-LIBVPX_REVISION="v1.15.1"
+LIBVPX_REVISION="v1.15.2"
 LIBOPUS_HEAD=0
 LIBOPUS_REVISION="v1.5.2"
 ENABLE_SWH_PLUGINS=1
 FFMPEG_HEAD=0
-FFMPEG_REVISION="origin/release/7.1"
+FFMPEG_REVISION="origin/release/8.0"
 FFMPEG_SUPPORT_H264=1
 FFMPEG_SUPPORT_H265=1
 FFMPEG_SUPPORT_JACK=0
@@ -81,9 +81,9 @@ ENABLE_ZIMG=1
 ZIMG_HEAD=0
 ZIMG_REVISION="51c3c7f750c2af61955377faad56e3ba1b03589f"
 DAV1D_HEAD=0
-DAV1D_REVISION="1.5.0"
+DAV1D_REVISION="1.5.1"
 AOM_HEAD=0
-AOM_REVISION="v3.11.0"
+AOM_REVISION="v3.13.1"
 SVTAV1_HEAD=0
 SVTAV1_REVISION="v3.1.0"
 VMAF_HEAD=0
@@ -99,13 +99,13 @@ OPENCV_CONTRIB_HEAD=0
 OPENCV_CONTRIB_REVISION="4.12.0"
 ENABLE_LIBWEBP=1
 LIBWEBP_HEAD=0
-LIBWEBP_REVISION="v1.5.0"
+LIBWEBP_REVISION="v1.6.0"
 ENABLE_LIBSPATIALAUDIO=1
 LIBSPATIALAUDIO_HEAD=0
 LIBSPATIALAUDIO_REVISION="origin/patch-1"
 ENABLE_WHISPERCPP=1
 WHISPERCPP_HEAD=0
-WHISPERCPP_REVISION="v1.7.4"
+WHISPERCPP_REVISION="v1.8.0"
 NV_CODEC_REVISION="sdk/12.0"
 MFX_DISPATCH_REVISION="1.25"
 
@@ -113,8 +113,8 @@ PYTHON_VERSION_DEFAULT=3.10
 PYTHON_VERSION_DARWIN=3.11
 PYTHON_VERSION=$(python3 --version | awk '{split($2, parts, "."); print parts[1] "." parts[2]}')
 
-QT_VERSION_DEFAULT=6.9.2
-QT_VERSION_DARWIN=6.9.2
+QT_VERSION_DEFAULT=6.8.3
+QT_VERSION_DARWIN=6.8.3
 
 # QT_INCLUDE_DIR="$(pkg-config --variable=prefix QtCore)/include"
 QT_INCLUDE_DIR=${QTDIR:+${QTDIR}/include}
@@ -1198,7 +1198,7 @@ function install_shotcut_linux {
   cmd install -p -c COPYING "$FINAL_INSTALL_DIR"
   cmd install -p -c "$QTDIR"/translations/qt_*.qm "$FINAL_INSTALL_DIR"/share/shotcut/translations
   cmd install -p -c "$QTDIR"/translations/qtbase_*.qm "$FINAL_INSTALL_DIR"/share/shotcut/translations
-  cmd install -p -c "$QTDIR"/lib/libQt6{Charts,Core,Core5Compat,DBus,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlMeta,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,WaylandClient,WaylandEglClientHwIntegration,Widgets,Xml,X11Extras,XcbQpa}.so.6 "$FINAL_INSTALL_DIR"/lib
+  cmd install -p -c "$QTDIR"/lib/libQt6{Charts,Core,Core5Compat,DBus,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlMeta,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,WaylandClient,WaylandEglClientHwIntegration,WebSockets,Widgets,Xml,X11Extras,XcbQpa}.so.6 "$FINAL_INSTALL_DIR"/lib
   cmd install -p -c "$QTDIR"/lib/lib{icudata,icui18n,icuuc}.so* "$FINAL_INSTALL_DIR"/lib
   cmd install -d "$FINAL_INSTALL_DIR"/lib/qt6/sqldrivers
   cmd cp -a "$QTDIR"/plugins/{egldeviceintegrations,generic,iconengines,imageformats,multimedia,platforminputcontexts,platforms,platformthemes,tls,wayland-decoration-client,wayland-graphics-integration-client,wayland-shell-integration,xcbglintegrations} "$FINAL_INSTALL_DIR"/lib/qt6
@@ -1673,7 +1673,7 @@ function configure_compile_install_all {
     for lib in "$FINAL_INSTALL_DIR"/lib/qt6/{egldeviceintegrations,generic,iconengines,imageformats,multimedia,platforminputcontexts,platforms,platformthemes,tls,wayland-decoration-client,wayland-graphics-integration-client,wayland-shell-integration,xcbglintegrations}/*.so; do
       bundle_libs "$lib"
     done
-    for lib in "$FINAL_INSTALL_DIR"/{lib,lib/mlt,lib/frei0r-1,lib/ladspa,lib/va}/*.so*; do
+    for lib in "$FINAL_INSTALL_DIR"/{lib,lib/mlt-7,lib/frei0r-1,lib/ladspa,lib/va}/*.so*; do
       bundle_libs "$lib"
     done
     bundle_libs "$FINAL_INSTALL_DIR"/bin/glaxnimate
@@ -2191,7 +2191,7 @@ End-of-shotcut-wrapper
       cmd rm -rf Shotcut/Shotcut.app/share/doc
       cmd rm -rf Shotcut/Shotcut.app/share/man
     fi
-    cmd tar -cJvf "$tarball" Shotcut
+    cmd tar -C Shotcut -cJvf "$tarball" Shotcut.app
   fi
 
   if [ "$ACTION_CLEANUP" = "1" ]; then
