@@ -18,23 +18,33 @@
 #include "transcribeaudiodialog.h"
 
 #include "Logger.h"
+#include "dialogs/filedownloaddialog.h"
 #include "docks/timelinedock.h"
 #include "mainwindow.h"
+#include "models/extensionmodel.h"
 #include "qmltypes/qmlapplication.h"
 #include "shotcut_mlt_properties.h"
 #include "util.h"
 
 #include <MltProducer.h>
 #include <QCheckBox>
+#include <QClipboard>
 #include <QComboBox>
 #include <QDialogButtonBox>
 #include <QFileDialog>
 #include <QGridLayout>
+#include <QHeaderView>
 #include <QLabel>
 #include <QLineEdit>
 #include <QListWidget>
+#include <QMenu>
+#include <QMessageBox>
 #include <QPushButton>
 #include <QSpinBox>
+#include <QTreeView>
+
+static const QString WHISPER_MODEL_EXTENSION_URL = QStringLiteral(
+    "https://check.shotcut.org/whispermodel.qml");
 
 // List of supported languages from whispercpp
 static const std::vector<const char *> whisperLanguages = {
@@ -70,6 +80,7 @@ static void fillLanguages(QComboBox *combo)
 TranscribeAudioDialog::TranscribeAudioDialog(const QString &trackName, QWidget *parent)
     : QDialog(parent)
 {
+    m_model.load(QmlExtension::WHISPER_ID);
     setWindowTitle(tr("Speech to Text"));
     setWindowModality(QmlApplication::dialogModality());
 
@@ -203,6 +214,7 @@ TranscribeAudioDialog::TranscribeAudioDialog(const QString &trackName, QWidget *
     configLayout->addWidget(new QLabel(tr("GGML Model")), 2, 0, Qt::AlignRight);
     m_modelLabel = new QLineEdit(this);
     m_modelLabel->setFixedWidth(maxPathWidth);
+    m_modelLabel->setPlaceholderText(tr("Select a model or browse to choose one"));
     m_modelLabel->setReadOnly(true);
     configLayout->addWidget(m_modelLabel, 2, 1, Qt::AlignLeft);
     QPushButton *modelBrowseButton = new QPushButton(this);
@@ -225,6 +237,43 @@ TranscribeAudioDialog::TranscribeAudioDialog(const QString &trackName, QWidget *
     });
     configLayout->addWidget(modelBrowseButton, 2, 2, Qt::AlignLeft);
 
+    // Update Model button
+    QPushButton *updateModelsButton = new QPushButton(tr("Refresh Models"), this);
+    connect(updateModelsButton,
+            &QAbstractButton::clicked,
+            this,
+            &TranscribeAudioDialog::refreshModels);
+    configLayout->addWidget(updateModelsButton, 3, 1, Qt::AlignLeft);
+
+    // List of models
+    m_table = new QTreeView();
+    m_table->setSelectionMode(QAbstractItemView::SingleSelection);
+    m_table->setSelectionBehavior(QAbstractItemView::SelectRows);
+    m_table->setItemsExpandable(false);
+    m_table->setRootIsDecorated(false);
+    m_table->setUniformRowHeights(true);
+    m_table->setSortingEnabled(false);
+    m_table->setModel(&m_model);
+    m_table->setWordWrap(false);
+    m_table->header()->setStretchLastSection(false);
+    qreal rowHeight = fontMetrics().height() * devicePixelRatioF();
+    m_table->header()->setMinimumSectionSize(rowHeight);
+    m_table->header()->setSectionResizeMode(ExtensionModel::COLUMN_STATUS, QHeaderView::Fixed);
+    m_table->setColumnWidth(ExtensionModel::COLUMN_STATUS, rowHeight);
+    m_table->header()->setSectionResizeMode(ExtensionModel::COLUMN_NAME, QHeaderView::Stretch);
+    m_table->header()->setSectionResizeMode(ExtensionModel::COLUMN_SIZE, QHeaderView::Fixed);
+    m_table->setColumnWidth(ExtensionModel::COLUMN_SIZE,
+                            fontMetrics().horizontalAdvance("XXX.XX XXX") * devicePixelRatioF()
+                                + 12);
+    connect(m_table, &QAbstractItemView::clicked, this, &TranscribeAudioDialog::onModelRowClicked);
+    m_table->setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(m_table,
+            &QWidget::customContextMenuRequested,
+            this,
+            &TranscribeAudioDialog::showModelContextMenu);
+
+    configLayout->addWidget(m_table, 4, 0, 1, 3);
+
     grid->addWidget(m_configWidget, 6, 0, 1, 2);
 
     // Add a button box to the dialog
@@ -246,7 +295,10 @@ TranscribeAudioDialog::TranscribeAudioDialog(const QString &trackName, QWidget *
     }
     m_buttonBox->addButton(configButton, QDialogButtonBox::ActionRole);
     grid->addWidget(m_buttonBox, 7, 0, 1, 2);
-    connect(m_buttonBox, SIGNAL(clicked(QAbstractButton *)), this, SLOT(clicked(QAbstractButton *)));
+    connect(m_buttonBox,
+            SIGNAL(clicked(QAbstractButton *)),
+            this,
+            SLOT(onButtonClicked(QAbstractButton *)));
 
     setLayout(grid);
     setModal(true);
@@ -265,7 +317,7 @@ QList<int> TranscribeAudioDialog::tracks()
     return tracks;
 }
 
-void TranscribeAudioDialog::clicked(QAbstractButton *button)
+void TranscribeAudioDialog::onButtonClicked(QAbstractButton *button)
 {
     QDialogButtonBox::ButtonRole role = m_buttonBox->buttonRole(button);
     if (role == QDialogButtonBox::AcceptRole) {
@@ -279,6 +331,28 @@ void TranscribeAudioDialog::clicked(QAbstractButton *button)
     }
 }
 
+void TranscribeAudioDialog::onModelRowClicked(const QModelIndex &index)
+{
+    if (!m_model.downloaded(index.row())) {
+        QMessageBox qDialog(QMessageBox::Question,
+                            tr("Download Model"),
+                            tr("Are you sure you want to download %1?\n%2 of storage will be used")
+                                .arg(m_model.getName(index.row()))
+                                .arg(m_model.getFormattedDataSize(index.row())),
+                            QMessageBox::No | QMessageBox::Yes,
+                            this);
+        qDialog.setDefaultButton(QMessageBox::Yes);
+        qDialog.setEscapeButton(QMessageBox::No);
+        qDialog.setWindowModality(QmlApplication::dialogModality());
+        int result = qDialog.exec();
+        if (result == QMessageBox::Yes) {
+            downloadModel(index.row());
+        }
+    }
+    setCurrentModel(index.row());
+    updateWhisperStatus();
+}
+
 QString TranscribeAudioDialog::name()
 {
     return m_name->text();
@@ -304,6 +378,83 @@ bool TranscribeAudioDialog::includeNonspoken()
     return m_nonspoken->checkState() == Qt::Checked;
 }
 
+void TranscribeAudioDialog::showEvent(QShowEvent *event)
+{
+    QDialog::showEvent(event);
+    bool modelFound = QFileInfo(Settings.whisperModel()).exists();
+    if (modelFound) {
+        return;
+    }
+
+    // No model is found. Offer to download one
+    QMessageBox qDialog(QMessageBox::Question,
+                        tr("Download Model"),
+                        tr("No models found. Download a standard model?"),
+                        QMessageBox::No | QMessageBox::Yes,
+                        this);
+    qDialog.setDefaultButton(QMessageBox::Yes);
+    qDialog.setEscapeButton(QMessageBox::No);
+    qDialog.setWindowModality(QmlApplication::dialogModality());
+    int result = qDialog.exec();
+    if (result == QMessageBox::Yes) {
+        refreshModels(false);
+        int index = m_model.getStandardIndex();
+        downloadModel(index);
+        setCurrentModel(index);
+        updateWhisperStatus();
+    }
+}
+
+void TranscribeAudioDialog::refreshModels(bool report)
+{
+    QString localDst = QmlExtension::appDir(QmlExtension::WHISPER_ID)
+                           .absoluteFilePath(QmlExtension::extensionFileName("whisper"));
+    FileDownloadDialog dlDialog(tr("Refresh Models"), this);
+    dlDialog.setSrc(WHISPER_MODEL_EXTENSION_URL);
+    dlDialog.setDst(localDst);
+    if (dlDialog.start() && report) {
+        m_model.load(QmlExtension::WHISPER_ID);
+        QMessageBox qDialog(QMessageBox::Information,
+                            tr("Refresh Models"),
+                            tr("Models refreshed"),
+                            QMessageBox::Ok,
+                            this);
+        qDialog.setWindowModality(QmlApplication::dialogModality());
+        qDialog.exec();
+    } else if (report) {
+        QMessageBox qDialog(QMessageBox::Critical,
+                            tr("Refresh Models"),
+                            tr("Failed to refresh models"),
+                            QMessageBox::Ok,
+                            this);
+        qDialog.setWindowModality(QmlApplication::dialogModality());
+        qDialog.exec();
+    }
+}
+
+void TranscribeAudioDialog::downloadModel(int index)
+{
+    FileDownloadDialog dlDialog(tr("Download Model"), this);
+    dlDialog.setSrc(m_model.url(index));
+    dlDialog.setDst(m_model.localPath(index));
+    dlDialog.start();
+}
+
+void TranscribeAudioDialog::setCurrentModel(int index)
+{
+    if (m_model.downloaded(index)) {
+        QString path = m_model.localPath(index);
+        if (QFileInfo(path).exists()) {
+            LOG_INFO() << "Model found" << path;
+            Settings.setWhisperModel(path);
+        } else {
+            LOG_ERROR() << "Model not found" << path;
+        }
+    } else {
+        LOG_ERROR() << "Model not downloaded" << m_model.getName(index);
+    }
+}
+
 void TranscribeAudioDialog::updateWhisperStatus()
 {
     bool exeFound = QFileInfo(Settings.whisperExe()).isExecutable();
@@ -339,6 +490,41 @@ void TranscribeAudioDialog::updateWhisperStatus()
         QPalette palette;
         palette.setColor(QPalette::Text, Qt::red);
         m_modelLabel->setPalette(palette);
-        m_modelLabel->setToolTip(tr("GGML model not found"));
+        if (m_modelLabel->text().isEmpty()) {
+            m_modelLabel->setText(m_modelLabel->placeholderText());
+            m_modelLabel->setToolTip(tr("Select a model"));
+        } else {
+            m_modelLabel->setToolTip(tr("GGML model not found"));
+        }
     }
+
+    QModelIndex index = m_model.getIndexForPath(Settings.whisperModel());
+    m_table->setCurrentIndex(index);
+}
+
+void TranscribeAudioDialog::showModelContextMenu(QPoint p)
+{
+    QModelIndex index = m_table->indexAt(p);
+    if (!index.isValid() || !m_model.downloaded(index.row())) {
+        updateWhisperStatus();
+        return;
+    }
+    QMenu *menu = new QMenu(tr("Model"));
+    QAction *action = new QAction(tr("Delete Model"), this);
+    connect(action, &QAction::triggered, this, [&]() { m_model.deleteFile(index.row()); });
+    QIcon icon = QIcon::fromTheme("edit-delete",
+                                  QIcon(":/icons/oxygen/32x32/actions/edit-delete.png"));
+    action->setIcon(icon);
+    menu->addAction(action);
+    action = new QAction(tr("Copy Model URL to Clipboard"), this);
+    connect(action, &QAction::triggered, this, [&]() {
+        QString url = m_model.url(index.row());
+        QGuiApplication::clipboard()->setText(url);
+    });
+    icon = QIcon::fromTheme("edit-copy", QIcon(":/icons/oxygen/32x32/actions/edit-copy.png"));
+    action->setIcon(icon);
+    menu->addAction(action);
+    menu->popup(QCursor::pos());
+    menu->exec();
+    updateWhisperStatus();
 }
