@@ -48,6 +48,7 @@
 #include <QInputDialog>
 #include <QItemSelectionModel>
 #include <QKeyEvent>
+#include <QLabel>
 #include <QMenu>
 #include <QPainter>
 #include <QPushButton>
@@ -464,6 +465,15 @@ PlaylistDock::PlaylistDock(QWidget *parent)
     toolbar->addAction(Actions["playlistViewTilesAction"]);
     toolbar->addAction(Actions["playlistViewIconsAction"]);
     toolbar->addSeparator();
+    m_label = new QLabel(toolbar);
+    toolbar->addWidget(m_label);
+    connect(m_proxyModel,
+            &QAbstractItemModel::modelAboutToBeReset,
+            this,
+            &PlaylistDock::clearStatus);
+    connect(m_proxyModel, &QAbstractItemModel::modelReset, this, &PlaylistDock::updateStatus);
+    connect(m_proxyModel, &QAbstractItemModel::rowsInserted, this, &PlaylistDock::updateStatus);
+    connect(m_proxyModel, &QAbstractItemModel::rowsRemoved, this, &PlaylistDock::updateStatus);
     ui->verticalLayout->addWidget(toolbar);
     ui->verticalLayout->addSpacing(2);
 
@@ -1239,11 +1249,7 @@ Mlt::Playlist *PlaylistDock::binPlaylist()
 {
     LongUiTask longTask(QObject::tr("Generating Playlist for Bin"));
     auto items = ui->treeWidget->selectedItems();
-    if (ui->treeWidget->topLevelItem(0)->isSelected() || items.isEmpty()) {
-        // ALL
-        m_binPlaylist = *m_model.playlist();
-        return &m_binPlaylist;
-    }
+    auto isAll = ui->treeWidget->topLevelItem(0)->isSelected() || items.isEmpty();
     auto bin = items.first()->text(0);
     m_binPlaylist.clear();
     auto count = m_model.playlist()->count();
@@ -1251,7 +1257,7 @@ Mlt::Playlist *PlaylistDock::binPlaylist()
         Mlt::ClipInfo info;
         m_model.playlist()->clip_info(i, &info);
         if (info.producer && info.producer->is_valid()
-            && bin == info.producer->get(kShotcutBinsProperty))
+            && (isAll || bin == info.producer->get(kShotcutBinsProperty)))
             m_binPlaylist.append(*info.producer, info.frame_in, info.frame_out);
         longTask.reportProgress(tr("Appending"), i, count);
     }
@@ -2117,6 +2123,17 @@ void PlaylistDock::on_treeWidget_itemSelectionChanged()
         }
 }
 
+void PlaylistDock::clearStatus()
+{
+    m_label->setText("...");
+}
+
+void PlaylistDock::updateStatus()
+{
+    auto n = m_proxyModel->rowCount();
+    m_label->setText(n > 0 ? tr("%n item(s)", nullptr, n) : "");
+}
+
 void BinTree::dropEvent(QDropEvent *event)
 {
     auto position = dropIndicatorPosition();
