@@ -107,6 +107,7 @@ signals:
     void dragging(const QPointF &pos, int duration);
     void dropped();
     void dropAccepted(const QString &xml);
+    void gainChanged(double gain);
     void fadeInChanged(int duration);
     void fadeOutChanged(int duration);
     void selected(Mlt::Producer *producer);
@@ -154,14 +155,16 @@ public slots:
     void setTrackLock(int trackIndex, bool lock);
     bool moveClip(int fromTrack, int toTrack, int clipIndex, int position, bool ripple);
     void onClipMoved(int fromTrack, int toTrack, int clipIndex, int position, bool ripple);
-    bool trimClipIn(int trackIndex, int clipIndex, int oldClipIndex, int delta, bool ripple);
-    bool trimClipOut(int trackIndex, int clipIndex, int delta, bool ripple);
+    bool trimClipIn(
+        int trackIndex, int clipIndex, int oldClipIndex, int delta, bool ripple, bool roll);
+    bool trimClipOut(int trackIndex, int clipIndex, int delta, bool ripple, bool roll);
     void insert(int trackIndex, int position = -1, const QString &xml = QString(), bool seek = true);
     void overwrite(int trackIndex,
                    int position = -1,
                    const QString &xml = QString(),
                    bool seek = true);
     void appendFromPlaylist(Mlt::Playlist *playlist, bool skipProxy, bool emptyTrack);
+    bool changeGain(int trackIndex, int clipIndex, double gain);
     void fadeIn(int trackIndex, int clipIndex = -1, int duration = -1);
     void fadeOut(int trackIndex, int clipIndex = -1, int duration = -1);
     void seekPreviousEdit();
@@ -224,15 +227,17 @@ private:
     void reportSelectionChange();
     void applyCopiedFiltersToSelectdClips();
     void insertOrOverwriteDrop(int trackIndex, int position, const QString &xml);
+    void freezeFrame();
+    void addGenerator(QWidget *widget);
 
     QQuickWidget m_quickView;
     MultitrackModel m_model;
     MarkersModel m_markersModel;
     SubtitlesModel m_subtitlesModel;
     SubtitlesSelectionModel m_subtitlesSelectionModel;
-    int m_position;
+    int m_position{-1};
     std::unique_ptr<Timeline::UpdateCommand> m_updateCommand;
-    bool m_ignoreNextPositionChange;
+    bool m_ignoreNextPositionChange{false};
     struct Selection
     {
         QList<QPoint> selectedClips; // x is the clip index, y is the track index
@@ -246,8 +251,8 @@ private:
     QTimer m_selectionSignalTimer;
     std::unique_ptr<Timeline::TrimCommand> m_trimCommand;
     std::unique_ptr<UndoHelper> m_undoHelper;
-    int m_trimDelta;
-    int m_transitionDelta;
+    int m_trimDelta{0};
+    int m_transitionDelta{0};
     bool m_isRecording{false};
     std::unique_ptr<AbstractJob> m_recordJob;
     QTimer m_recordingTimer;
@@ -274,6 +279,7 @@ private slots:
     void onTimelineRightClicked();
     void onClipRightClicked();
     void onNoMoreEmptyTracks(bool isAudio);
+    void addGenerator();
 };
 
 #endif // TIMELINEDOCK_H
