@@ -163,11 +163,8 @@ int Controller::open(const QString &url, const QString &urlToSave, bool skipConv
             delete newProducer;
             newProducer = new Mlt::Producer(profile(), myUrl.toUtf8().constData());
         }
-        if (m_url.isEmpty() && QString(newProducer->get("xml")) == "was here") {
-            if (newProducer->get_int("_original_type") != mlt_service_tractor_type
-                || (newProducer->get_int("_original_type") == mlt_service_tractor_type
-                    && newProducer->get(kShotcutXmlProperty)))
-                m_url = urlToSave;
+        if (m_url.isEmpty() && isProjectProducer(newProducer)) {
+            m_url = urlToSave;
         }
         Producer *producer = setupNewProducer(newProducer);
         producer->set(kShotcutSkipConvertProperty, skipConvert);
@@ -499,11 +496,17 @@ bool Controller::saveXML(const QString &filename,
         c.set("no_root", 1);
         c.set("title",
               QStringLiteral("Shotcut version ").append(SHOTCUT_VERSION).toUtf8().constData());
+
+        // Save the consumer of this service so it can be restored.
+        auto saveConsumer = mlt_service_consumer(s.consumer()->get_service());
         c.connect(s);
         c.start();
         if (ignore)
             s.set("ignore_points", ignore);
         auto xml = QString::fromUtf8(c.get(kMltXmlPropertyName));
+        // Restore the consumer that was previously on this service
+        mlt_service_set_consumer(s.get_service(), saveConsumer);
+
         if (!proxy && ProxyManager::filterXML(xml, root)) { // also verifies
             if (tempFile) {
                 QTextStream stream(tempFile);
@@ -543,7 +546,10 @@ QString Controller::XML(Service *service, bool withProfile, bool withMetadata)
               : (m_producer && m_producer->is_valid()) ? m_producer->get_service()
                                                        : nullptr);
     if (!s.is_valid())
-        return "";
+        return QString();
+
+    // Save the consumer of this service so it can be restored.
+    auto saveConsumer = mlt_service_consumer(s.consumer()->get_service());
     int ignore = s.get_int("ignore_points");
     if (ignore)
         s.set("ignore_points", 0);
@@ -557,6 +563,8 @@ QString Controller::XML(Service *service, bool withProfile, bool withMetadata)
     c.start();
     if (ignore)
         s.set("ignore_points", ignore);
+    // Restore the consumer that was previously on this service
+    mlt_service_set_consumer(s.get_service(), saveConsumer);
     return QString::fromUtf8(c.get(kMltXmlPropertyName));
 }
 
@@ -656,11 +664,16 @@ bool Controller::isSeekable(Producer *p) const
     return seekable;
 }
 
+int Controller::maxFrameCount() const
+{
+    return qRound(m_profile.fps() * 7 * 24 * 3600);
+}
+
 bool Controller::isLiveProducer(Producer *p) const
 {
     Mlt::Producer *producer = p ? p : m_producer.data();
     if (producer && producer->is_valid()) {
-        return producer->get_length() == std::numeric_limits<int>::max();
+        return producer->get_length() > maxFrameCount();
     }
     return false;
 }
@@ -718,6 +731,13 @@ bool Controller::isFileProducer(Service *service) const
     return false;
 }
 
+bool Controller::isProjectProducer(Service *service)
+{
+    return service && service->is_valid() && QString(service->get("xml")) == "was here"
+           && (service->get_int("_original_type") != mlt_service_tractor_type
+               || service->get(kShotcutXmlProperty));
+}
+
 void Controller::rewind(bool forceChangeDirection)
 {
     if (!m_producer || !m_producer->is_valid())
@@ -1127,6 +1147,7 @@ void Controller::copyFilters(Producer &fromProducer,
             Mlt::Filter toFilter(MLT.profile(), fromFilter->get("mlt_service"));
             if (toFilter.is_valid()) {
                 toFilter.inherit(*fromFilter);
+                toFilter.clear("disable");
                 // Force any 2-pass filters to require re-analysis
                 toFilter.clear("results");
                 toProducer.attach(toFilter);
@@ -1234,13 +1255,14 @@ void Controller::adjustFilters(Producer &producer, int index)
                     filter->anim_set(key,
                                      1,
                                      filter->get_length()
-                                         - filter->get_int(kShotcutAnimOutProperty));
+                                         - std::max(filter->get_int(kShotcutAnimOutProperty), 2));
                     filter->anim_set(key, 0, filter->get_length() - 1);
                 } else if (filterName == "fadeOutMovit") {
                     filter->clear("opacity");
                     filter->anim_set("opacity",
                                      1,
-                                     filter->get_length() - filter->get_int(kShotcutAnimOutProperty),
+                                     filter->get_length()
+                                         - std::max(filter->get_int(kShotcutAnimOutProperty), 2),
                                      0,
                                      mlt_keyframe_smooth);
                     filter->anim_set("opacity", 0, filter->get_length() - 1);
@@ -1249,7 +1271,7 @@ void Controller::adjustFilters(Producer &producer, int index)
                     filter->anim_set("level",
                                      0,
                                      filter->get_length()
-                                         - filter->get_int(kShotcutAnimOutProperty));
+                                         - std::max(filter->get_int(kShotcutAnimOutProperty), 2));
                     filter->anim_set("level", -60, filter->get_length() - 1);
                 } else if (filter->get_int(kShotcutAnimOutProperty) > 0) {
                     // Update simple keyframes.
@@ -1403,13 +1425,15 @@ void Controller::adjustFilter(
                 filter->clear(key);
                 filter->anim_set(key,
                                  1,
-                                 filter->get_length() - filter->get_int(kShotcutAnimOutProperty));
+                                 filter->get_length()
+                                     - std::max(filter->get_int(kShotcutAnimOutProperty), 2));
                 filter->anim_set(key, 0, filter->get_length() - 1);
             } else if (filterName == "fadeOutMovit") {
                 filter->clear("opacity");
                 filter->anim_set("opacity",
                                  1,
-                                 filter->get_length() - filter->get_int(kShotcutAnimOutProperty),
+                                 filter->get_length()
+                                     - std::max(filter->get_int(kShotcutAnimOutProperty), 2),
                                  0,
                                  mlt_keyframe_smooth);
                 filter->anim_set("opacity", 0, filter->get_length() - 1);
@@ -1417,7 +1441,8 @@ void Controller::adjustFilter(
                 filter->clear("level");
                 filter->anim_set("level",
                                  0,
-                                 filter->get_length() - filter->get_int(kShotcutAnimOutProperty));
+                                 filter->get_length()
+                                     - std::max(filter->get_int(kShotcutAnimOutProperty), 2));
                 filter->anim_set("level", -60, filter->get_length() - 1);
             }
             emit MAIN.serviceInChanged(inDelta, filter);
@@ -1440,13 +1465,15 @@ void Controller::adjustFilter(
                 filter->clear(key);
                 filter->anim_set(key,
                                  1,
-                                 filter->get_length() - filter->get_int(kShotcutAnimOutProperty));
+                                 filter->get_length()
+                                     - std::max(filter->get_int(kShotcutAnimOutProperty), 2));
                 filter->anim_set(key, 0, filter->get_length() - 1);
             } else if (filterName == "fadeOutMovit") {
                 filter->clear("opacity");
                 filter->anim_set("opacity",
                                  1,
-                                 filter->get_length() - filter->get_int(kShotcutAnimOutProperty),
+                                 filter->get_length()
+                                     - std::max(filter->get_int(kShotcutAnimOutProperty), 2),
                                  0,
                                  mlt_keyframe_smooth);
                 filter->anim_set("opacity", 0, filter->get_length() - 1);
@@ -1454,7 +1481,8 @@ void Controller::adjustFilter(
                 filter->clear("level");
                 filter->anim_set("level",
                                  0,
-                                 filter->get_length() - filter->get_int(kShotcutAnimOutProperty));
+                                 filter->get_length()
+                                     - std::max(filter->get_int(kShotcutAnimOutProperty), 2));
                 filter->anim_set("level", -60, filter->get_length() - 1);
             }
             emit MAIN.serviceOutChanged(outDelta, filter);
@@ -1537,6 +1565,24 @@ void Controller::setSavedProducer(Mlt::Producer *producer)
     m_savedProducer.reset(new Mlt::Producer(producer));
 }
 
+Link *Controller::getLink(const QString &name, Service *service)
+{
+    if (service->type() == mlt_service_chain_type) {
+        Chain chain(*service);
+        int link_count = chain.link_count();
+        for (int j = 0; j < link_count; j++) {
+            Link *link = chain.link(j);
+            if (link && link->is_valid()) {
+                if (name == QString::fromUtf8(link->get(kShotcutFilterProperty))
+                    || name == QString::fromUtf8(link->get("mlt_service")))
+                    return link;
+                delete link;
+            }
+        }
+    }
+    return nullptr;
+}
+
 Filter *Controller::getFilter(const QString &name, Service *service)
 {
     for (int i = 0; i < service->filter_count(); i++) {
