@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2022-2023 Meltytech, LLC
+ * Copyright (c) 2022-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include "actions.h"
 #include "docks/timelinedock.h"
 #include "qmltypes/qmlapplication.h"
+#include "util.h"
 
 #include <QColorDialog>
 #include <QLabel>
@@ -73,9 +74,7 @@ void QmlMarkerMenu::popup()
     connect(&colorAction, &QAction::triggered, this, [&]() {
         QColor markerColor = m_timeline->markersModel()->getMarker(m_index).color;
         QColorDialog colorDialog(markerColor);
-#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
-        colorDialog.setOptions(QColorDialog::DontUseNativeDialog);
-#endif
+        colorDialog.setOptions(Util::getColorDialogOptions());
         colorDialog.setModal(QmlApplication::dialogModality());
         if (colorDialog.exec() == QDialog::Accepted) {
             m_timeline->markersModel()->setColor(m_index, colorDialog.currentColor());
