@@ -942,7 +942,7 @@ ShotcutSettings::TimelineScrolling ShotcutSettings::timelineScrolling() const
 
 bool ShotcutSettings::timelineAutoAddTracks() const
 {
-    return settings.value("timeline/autoAddTracks", false).toBool();
+    return settings.value("timeline/autoAddTracks", true).toBool();
 }
 
 void ShotcutSettings::setTimelineAutoAddTracks(bool b)
@@ -966,7 +966,7 @@ void ShotcutSettings::setTimelineRectangleSelect(bool b)
 
 bool ShotcutSettings::timelineAdjustGain() const
 {
-    return settings.value("timeline/adjustGain", true).toBool();
+    return settings.value("timeline/adjustGain", false).toBool();
 }
 
 void ShotcutSettings::setTimelineAdjustGain(bool b)
@@ -1523,6 +1523,36 @@ bool ShotcutSettings::subtitlesShowPrevNext() const
     return settings.value("subtitles/showPrevNext", true).toBool();
 }
 
+QString ShotcutSettings::speechLanguage() const
+{
+    return settings.value("speech/language", QStringLiteral("a")).toString();
+}
+
+void ShotcutSettings::setSpeechLanguage(const QString &code)
+{
+    settings.setValue("speech/language", code);
+}
+
+QString ShotcutSettings::speechVoice() const
+{
+    return settings.value("speech/voice", QString()).toString();
+}
+
+void ShotcutSettings::setSpeechVoice(const QString &voiceId)
+{
+    settings.setValue("speech/voice", voiceId);
+}
+
+double ShotcutSettings::speechSpeed() const
+{
+    return settings.value("speech/speed", 1.0).toDouble();
+}
+
+void ShotcutSettings::setSpeechSpeed(double speed)
+{
+    settings.setValue("speech/speed", speed);
+}
+
 void ShotcutSettings::setWhisperExe(const QString &path)
 {
     settings.setValue("subtitles/whisperExe", path);
@@ -1590,7 +1620,7 @@ void ShotcutSettings::setBackupPeriod(int minutes)
 
 mlt_time_format ShotcutSettings::timeFormat() const
 {
-    return (mlt_time_format) settings.value("timeFormat", mlt_time_smpte_df).toInt();
+    return (mlt_time_format) settings.value("timeFormat", mlt_time_clock).toInt();
 }
 
 void ShotcutSettings::setTimeFormat(int format)
@@ -1608,3 +1638,47 @@ void ShotcutSettings::setAskFlatpakWrappers(bool b)
 {
     settings.setValue("flatpakWrappers", b);
 }
+
+QString ShotcutSettings::dockerPath() const
+{
+#if defined(Q_OS_MAC)
+    return settings.value("dockerPath", "/usr/local/bin/docker").toString();
+#elif defined(Q_OS_WIN)
+    return settings.value("dockerPath", "C:/Program Files/Docker/Docker/resources/bin/docker.exe")
+        .toString();
+#else
+    return settings.value("dockerPath", "docker").toString();
+#endif
+}
+
+void ShotcutSettings::setDockerPath(const QString &path)
+{
+    settings.setValue("dockerPath", path);
+}
+
+QString ShotcutSettings::chromiumPath() const
+{
+#if defined(Q_OS_MAC)
+    return settings.value("chromiumPath", "/Applications/Google Chrome.app").toString();
+#elif defined(Q_OS_WIN)
+    return settings.value("chromiumPath", "C:/Program Files/Google/Chrome/Application/chrome.exe")
+        .toString();
+#else
+    return settings.value("chromiumPath", "/usr/bin/chromium-browser").toString();
+#endif
+}
+
+void ShotcutSettings::setChromiumPath(const QString &path)
+{
+    settings.setValue("chromiumPath", path);
+}
+
+QString ShotcutSettings::screenRecorderPath() const
+{
+    return settings.value("screenRecorderPath", "obs").toString();
+}
+
+void ShotcutSettings::setScreenRecorderPath(const QString &path)
+{
+    settings.setValue("screenRecorderPath", path);
+}
