@@ -306,6 +306,12 @@ public:
     void setTimeFormat(int format);
     bool askFlatpakWrappers();
     void setAskFlatpakWrappers(bool b);
+    QString dockerPath() const;
+    void setDockerPath(const QString &path);
+    QString chromiumPath() const;
+    void setChromiumPath(const QString &path);
+    QString screenRecorderPath() const;
+    void setScreenRecorderPath(const QString &path);
 
     // proxy
     bool proxyEnabled() const;
@@ -373,6 +379,14 @@ public:
     bool filesFoldersOpen() const;
     void setFilesFoldersOpen(bool b);
 
+    // Speech (Text-to-Speech dialog)
+    QString speechLanguage() const;
+    void setSpeechLanguage(const QString &code);
+    QString speechVoice() const;
+    void setSpeechVoice(const QString &voiceId);
+    double speechSpeed() const;
+    void setSpeechSpeed(double speed);
+
 public slots:
     void reset();
 
