@@ -19,7 +19,10 @@
 #define UTIL_H
 
 #include <MltProperties.h>
+#include <functional>
+#include <QColorDialog>
 #include <QFileDialog>
+#include <QPair>
 #include <QPalette>
 #include <QString>
 #include <QUrl>
@@ -64,6 +67,7 @@ public:
     static QString getFileHash(const QString &path);
     static QString getHash(Mlt::Properties &properties);
     static bool hasDriveLetter(const QString &path);
+    static QColorDialog::ColorDialogOptions getColorDialogOptions();
     static QFileDialog::Options getFileDialogOptions();
     static bool isMemoryLow();
     static QString removeQueryString(const QString &s);
@@ -92,6 +96,18 @@ public:
     static bool hasiPhoneAmbisonic(Mlt::Producer *producer);
     static bool installFlatpakWrappers(QWidget *parent);
     static QString getExecutable(QWidget *parent);
+    // Returns a pair of booleans: (dockerInstalled, imagePresent)
+    // imagePresent is only meaningful (true/false) if dockerInstalled is true; otherwise false.
+    static QPair<bool, bool> dockerStatus(const QString &imageName);
+    static bool isDockerImageCurrent(const QString &imageRef);
+    // Asynchronous version of isDockerImageCurrent. The callback is invoked on the GUI thread
+    // with the result. If any step fails (including docker not found), result is false.
+    // 'receiver' is used as the parent for internal QProcess objects (may be nullptr).
+    static void isDockerImageCurrentAsync(const QString &imageRef,
+                                          QObject *receiver,
+                                          std::function<void(bool)> callback);
+    static bool isChromiumAvailable();
+    static bool startDetached(const QString &program, const QStringList &arguments);
 };
 
 #endif // UTIL_H
