@@ -92,9 +92,7 @@ void GlaxnimateProducerWidget::on_colorButton_clicked()
         color = QColor(QFileInfo(m_producer->get("background")).baseName());
     }
     QColorDialog::ColorDialogOptions flags = QColorDialog::ShowAlphaChannel;
-#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
-    flags = flags | QColorDialog::DontUseNativeDialog;
-#endif
+    flags |= Util::getColorDialogOptions();
     auto newColor = QColorDialog::getColor(color, this, QString(), flags);
     if (newColor.isValid()) {
         auto rgb = newColor;
@@ -197,7 +195,7 @@ static void modifyJsonValue(QJsonValue &destValue, const QString &path, const QJ
 Mlt::Producer *GlaxnimateProducerWidget::newProducer(Mlt::Profile &profile)
 {
     // Get the file name.
-    auto filename = QmlApplication::getNextProjectFile("anim.rawr");
+    auto filename = QmlApplication::getNextProjectFile("anim-.rawr");
     if (filename.isEmpty()) {
         QString path = Settings.savePath();
         path.append("/%1.rawr");
